import path from 'node:path';
import { getComponentParts } from './fileReader';
export class BaseWorkspaceScanner {
    constructor(workspace, modulesPaths) {
        this.workspace = workspace;
        this.modulesPaths = modulesPaths;
    }
    /**
     * Get information about LWC modules contained in the workspace.
     */
    getModulesMap() {
        const modulesMap = [];
        this.findModuleDirs().forEach((dir) => {
            const moduleMap = this.scanAModule(dir);
            if (moduleMap) {
                modulesMap.push(moduleMap);
            }
        });
        return modulesMap;
    }
    scanAModule(moduleDir) {
        const { base } = path.parse(moduleDir);
        const namespace = this.getNamespace(moduleDir);
        const moduleParts = getComponentParts(moduleDir, namespace);
        if (!moduleParts) {
            return;
        }
        const moduleMap = {
            ownerModuleId: `${namespace}/${base}`,
            moduleParts,
        };
        return moduleMap;
    }
}
//# sourceMappingURL=scanner.js.map